==> polarion_rest_api_client-1.2.0-py3-none-any.whl: polarion_rest_api_client/open_api_client/models/workitem_approvals_single_get_response_data_relationships_user.py <==
# Copyright DB InfraGO AG and contributors
# SPDX-License-Identifier: Apache-2.0

from typing import TYPE_CHECKING, Any, Dict, List, Type, TypeVar, Union

from attrs import define as _attrs_define
from attrs import field as _attrs_field

from ..types import UNSET, Unset

if TYPE_CHECKING:
    from ..models.workitem_approvals_single_get_response_data_relationships_user_data import (
        WorkitemApprovalsSingleGetResponseDataRelationshipsUserData,
    )


T = TypeVar(
    "T", bound="WorkitemApprovalsSingleGetResponseDataRelationshipsUser"
)


@_attrs_define
class WorkitemApprovalsSingleGetResponseDataRelationshipsUser:
    """
    Attributes:
        data (Union[Unset, WorkitemApprovalsSingleGetResponseDataRelationshipsUserData]):
    """

    data: Union[
        Unset, "WorkitemApprovalsSingleGetResponseDataRelationshipsUserData"
    ] = UNSET
    additional_properties: Dict[str, Any] = _attrs_field(
        init=False, factory=dict
    )

    def to_dict(self) -> Dict[str, Any]:
        data: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.data, Unset):
            data = self.data.to_dict()

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({})
        if data is not UNSET:
            field_dict["data"] = data

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        from ..models.workitem_approvals_single_get_response_data_relationships_user_data import (
            WorkitemApprovalsSingleGetResponseDataRelationshipsUserData,
        )

        d = src_dict.copy()
        _data = d.pop("data", UNSET)
        data: Union[
            Unset, WorkitemApprovalsSingleGetResponseDataRelationshipsUserData
        ]
        if isinstance(_data, Unset):
            data = UNSET
        else:
            data = WorkitemApprovalsSingleGetResponseDataRelationshipsUserData.from_dict(
                _data
            )

        workitem_approvals_single_get_response_data_relationships_user_obj = (
            cls(
                data=data,
            )
        )

        workitem_approvals_single_get_response_data_relationships_user_obj.additional_properties = (
            d
        )
        return (
            workitem_approvals_single_get_response_data_relationships_user_obj
        )

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties

==> polarion_rest_api_client-1.4.1-py3-none-any.whl: polarion_rest_api_client/open_api_client/models/workitem_approvals_single_get_response_data_relationships_user.py <==
# Copyright DB InfraGO AG and contributors
# SPDX-License-Identifier: Apache-2.0

from collections.abc import Mapping
from typing import TYPE_CHECKING, Any, TypeVar, Union

from attrs import define as _attrs_define
from attrs import field as _attrs_field

from ..types import UNSET, Unset

if TYPE_CHECKING:
    from ..models.workitem_approvals_single_get_response_data_relationships_user_data import (
        WorkitemApprovalsSingleGetResponseDataRelationshipsUserData,
    )


T = TypeVar(
    "T", bound="WorkitemApprovalsSingleGetResponseDataRelationshipsUser"
)


@_attrs_define
class WorkitemApprovalsSingleGetResponseDataRelationshipsUser:
    """
    Attributes:
        data (Union[Unset, WorkitemApprovalsSingleGetResponseDataRelationshipsUserData]):
    """

    data: Union[
        Unset, "WorkitemApprovalsSingleGetResponseDataRelationshipsUserData"
    ] = UNSET
    additional_properties: dict[str, Any] = _attrs_field(
        init=False, factory=dict
    )

    def to_dict(self) -> dict[str, Any]:
        data: Union[Unset, dict[str, Any]] = UNSET
        if not isinstance(self.data, Unset):
            data = self.data.to_dict()

        field_dict: dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({})
        if data is not UNSET:
            field_dict["data"] = data

        return field_dict

    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        from ..models.workitem_approvals_single_get_response_data_relationships_user_data import (
            WorkitemApprovalsSingleGetResponseDataRelationshipsUserData,
        )

        d = dict(src_dict)
        _data = d.pop("data", UNSET)
        data: Union[
            Unset, WorkitemApprovalsSingleGetResponseDataRelationshipsUserData
        ]
        if isinstance(_data, Unset):
            data = UNSET
        else:
            data = WorkitemApprovalsSingleGetResponseDataRelationshipsUserData.from_dict(
                _data
            )

        workitem_approvals_single_get_response_data_relationships_user_obj = (
            cls(
                data=data,
            )
        )

        workitem_approvals_single_get_response_data_relationships_user_obj.additional_properties = (
            d
        )
        return (
            workitem_approvals_single_get_response_data_relationships_user_obj
        )

    @property
    def additional_keys(self) -> list[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties
